@@ -10,7 +10,6 @@ mod adult_liveness;
 pub(crate) mod adult_reader;
 mod chunk_records;
 mod elder_stores;
-mod map_storage;
 mod register_storage;
 mod sequence_storage;
 
@@ -28,7 +27,6 @@ use crate::routing::Prefix;
 use crate::types::{Chunk, PublicKey};
 use chunk_records::ChunkRecords;
 use elder_stores::ElderStores;
-use map_storage::MapStorage;
 use register_storage::RegisterStorage;
 use sequence_storage::SequenceStorage;
 use std::{
@@ -55,15 +53,9 @@ impl Metadata {
         capacity: Capacity,
     ) -> Result<Self> {
         let chunk_records = ChunkRecords::new(capacity);
-        let map_storage = MapStorage::new(path, used_space.max_capacity()); // to be removed so we don't care to implement this
         let sequence_storage = SequenceStorage::new(path, used_space.max_capacity()); // to be removed so we don't care to implement this
         let register_storage = RegisterStorage::new(path, used_space);
-        let elder_stores = ElderStores::new(
-            chunk_records,
-            map_storage,
-            sequence_storage,
-            register_storage,
-        );
+        let elder_stores = ElderStores::new(chunk_records, sequence_storage, register_storage);
         Ok(Self { elder_stores })
     }
 
